# coding=utf-8
from __future__ import print_function, absolute_import
from gm.api import *


# 买指定数量的股票
def buy_count(stock: str, count: int, price: float):
    return order_volume(symbol=stock, volume=count, price=price, order_type=OrderType_Market, side=OrderSide_Buy,
                        position_effect=PositionEffect_Open)


# 买指定数量的股票
def l_buy_count(stock: str, count: int, price: float):
    return order_volume(symbol=stock, volume=count, price=price, order_type=OrderType_Market, side=OrderSide_Buy,
                        position_effect=PositionEffect_Open)


# 卖指定数量的股票
def sell_count(stock: str, count: int, price: float):
    return order_volume(symbol=stock, volume=count, price=price, order_type=OrderType_Market, side=OrderSide_Sell,
                        position_effect=PositionEffect_Open)


# 卖指定数量的股票
def l_sell_count(stock: str, count: int, price: float):
    return order_volume(symbol=stock, volume=count, price=price, order_type=OrderType_Market, side=OrderSide_Sell,
                        position_effect=PositionEffect_Open)


# 调整仓位（到特定数量）
def order_target_count(stock: str, volume: int, price: float):
    order_cancel_all()
    return order_target_volume(symbol=stock, volume=volume, price=price, order_type=OrderType_Market,
                               position_side=PositionSide_Long)


# 调整仓位（到特定数量）
def l_order_target_count(stock: str, volume: int, price: float):
    order_cancel_all()
    return order_target_volume(symbol=stock, volume=volume, price=price, order_type=OrderType_Market,
                               position_side=PositionSide_Long)


# 调整仓位（到特定价值）
def order_target_money(stock: str, worth: int, price: float):
    order_cancel_all()
    return order_target_value(symbol=stock, value=worth, price=price, order_type=OrderType_Market,
                              position_side=PositionSide_Long)


# 调整仓位（到特定价值）
def l_order_target_money(stock: str, worth: int, price: float):
    order_cancel_all()
    return order_target_value(symbol=stock, value=worth, price=price, order_type=OrderType_Market,
                              position_side=PositionSide_Long)



# coding=utf-8
from __future__ import print_function, absolute_import
from datetime import datetime
import random
import os
from gm.api import *

_gm_libs_logs = {
    "dir_path": "",
}


# 获取日志地址
def l_get_log_path():
    global _gm_libs_logs
    return _gm_libs_logs["dir_path"]


# 日志输出且保存
def log_all(level: str, info: str, source: str = "", filetype: str = "common"):
    log(level=level, msg=info, source=source)
    text = "【{}】 {}".format(level, info)
    print(text)
    append(text, filetype)


# 日志不输出仅保存
def log_save(level: str, info: str, source: str = "", filetype: str = "common"):
    log(level=level, msg=info, source=source)
    text = "【{}】 {}".format(level, info)
    append(text, filetype)


# 追加信息到日志文件
def append(text: str, filetype: str = ""):
    global _gm_libs_logs
    parent_path = r"C:\Users\Public\gm_libs"

    if filetype not in _gm_libs_logs or _gm_libs_logs["dir_path"] == "":
        if _gm_libs_logs["dir_path"] == "":
            _gm_libs_logs["dir_path"] = datetime.today().strftime('%Y-%m-%d %H.%M.%S ') + "%s" % random.randint(1000000, 9999999)

        _gm_libs_logs[filetype] = True
        all_path = r"{}\{}".format(parent_path, _gm_libs_logs["dir_path"])

        if not os.path.exists(parent_path):
            os.mkdir(parent_path)
        if not os.path.exists(all_path):
            os.mkdir(all_path)
        log_file = open(r"{}\{}.log".format(all_path, filetype), "w+", encoding="utf-8")
    else:
        all_path = r"{}\{}".format(parent_path, _gm_libs_logs["dir_path"])
        log_file = open(r"{}\{}.log".format(all_path, filetype), "a", encoding="utf-8")

    log_file.writelines("{}\n".format(text))
    log_file.close()



# coding=utf-8
from __future__ import print_function, absolute_import
from gm.api import *


# 运行初始化
def l_init_run(context):
    context.l_statics = {
        "month": 0,  # 昨日月份
        "nav": [],  # 获得收益
    }


# 每日初始化
def l_init_day(context):
    context.today_str = context.now.strftime("%Y-%m-%d")